@@ -5,6 +5,7 @@ import asyncio
 import json
 import socket
 from dataclasses import dataclass
+from itertools import islice
 from typing import Any
 
 import aiohttp
@@ -14,16 +15,17 @@ import xmltodict
 from cachetools import TTLCache
 from yarl import URL
 
-from .exceptions import (
-    CybroConnectionError,
-    CybroConnectionTimeoutError,
-    CybroEmptyResponseError,
-    CybroError,
-)
-from .models import Device, VarType
+from .exceptions import CybroConnectionError
+from .exceptions import CybroConnectionTimeoutError
+from .exceptions import CybroEmptyResponseError
+from .exceptions import CybroError
+from .models import Device
+from .models import VarType
 
 VERSION_CACHE: TTLCache = TTLCache(maxsize=16, ttl=7200)
 
+VAR_CHUNK_SIZE: int = 25
+
 
 @dataclass
 class Cybro:
@@ -45,7 +47,7 @@ class Cybro:
         nad: int = 0,
         session: aiohttp.client.ClientSession | None = None,
     ) -> None:
-        """Defines a new Cybro scgi server session.
+        """Define a new Cybro scgi server session.
 
         Args:
             host_str: Cybro scgi server connection string
@@ -69,14 +71,14 @@ class Cybro:
             self.session = session
 
     async def disconnect(self) -> None:
-        """disconnect from cybro scgi server object"""
+        """Disconnect from cybro scgi server object."""
         if self.session is not None:
             await self.session.close()
             self.session = None
 
     @backoff.on_exception(
         backoff.expo,
-        tuple([CybroConnectionError, CybroConnectionTimeoutError, CybroError]),
+        {CybroConnectionError, CybroConnectionTimeoutError, CybroError},
         max_tries=3,
         logger=None,
     )
@@ -168,7 +170,9 @@ class Cybro:
     @backoff.on_exception(
         backoff.expo, CybroEmptyResponseError, max_tries=3, logger=None
     )
-    async def update(self, full_update: bool = False, plc_nad: int = 0) -> Device:
+    async def update(
+        self, full_update: bool = False, plc_nad: int = 0, device_type: int = 0
+    ) -> Device:
         """Get all variables in a single call.
 
         This method updates all variable information with a single call.
@@ -176,6 +180,7 @@ class Cybro:
         Args:
             full_update: Force a full update from the device Device.
             plc_nad: Address of PLC to read
+            device_type: 0 = undefined / generic PLC, 1 = HIQ-controller
 
         Returns:
             Cybro Device data.
@@ -213,6 +218,9 @@ class Cybro:
                 _vars[_controller + "sys.bytes_transferred"] = ""
                 _vars[_controller + "sys.comm_error_count"] = ""
                 _vars[_controller + "sys.alc_file"] = ""
+                # read / prepare specific vars for HIQ-controller
+                if device_type == 1:
+                    _vars = _add_hiq_tags(_vars, _controller)
 
             if not (data := await self.request(data=_vars)):
                 raise CybroEmptyResponseError(
@@ -223,24 +231,26 @@ class Cybro:
             self._device = Device(data, plc_nad=self.nad)
 
             if len(self._device.user_vars) > 0:
-                if not (data := await self.request(data=self._device.user_vars)):
-                    raise CybroEmptyResponseError(
-                        f"Cybro scgi server at {self.host}:{self.port} returned an empty"
-                        " response on full update"
-                    )
-
-                self._device.update_user_var_from_dict(data=data)
+                _user_vars = _get_chunk(self._device.user_vars, VAR_CHUNK_SIZE)
+                for _vars in _user_vars:
+                    if not (data := await self.request(data=_vars)):
+                        raise CybroEmptyResponseError(
+                            f"Cybro scgi server at {self.host}:{self.port} returned an empty"
+                            " response on full update"
+                        )
+                    self._device.update_user_var_from_dict(data=data)
 
             return self._device
 
         if len(self._device.user_vars) > 0:
-            if not (data := await self.request(data=self._device.user_vars)):
-                raise CybroEmptyResponseError(
-                    f"Cybro scgi server at {self.host}:{self.port} returned an empty"
-                    " response on full update"
-                )
-
-            self._device.update_user_var_from_dict(data=data)
+            _user_vars = _get_chunk(self._device.user_vars, VAR_CHUNK_SIZE)
+            for _vars in _user_vars:
+                if not (data := await self.request(data=_vars)):
+                    raise CybroEmptyResponseError(
+                        f"Cybro scgi server at {self.host}:{self.port} returned an empty"
+                        " response on user update"
+                    )
+                self._device.update_user_var_from_dict(data=data)
 
             return self._device
 
@@ -252,7 +262,7 @@ class Cybro:
     async def write_var(
         self, name: str, value: str, var_type: VarType = VarType.STR
     ) -> str | int | float | bool:
-        """write a single variable to scgi server"""
+        """Write a single variable to scgi server."""
         data = await self.request(data={name: value})
         return self._device.update_var(data, var_type=var_type)
 
@@ -262,7 +272,7 @@ class Cybro:
     async def read_var(
         self, name: str, var_type: VarType = VarType.STR
     ) -> str | int | float | bool:
-        """read a single variable from scgi server"""
+        """Read a single variable from scgi server."""
         if not (data := await self.request(data=name)):
             raise CybroEmptyResponseError(
                 f"Cybro scgi server at {self.host}:{self.port} returned an empty"
@@ -277,7 +287,7 @@ class Cybro:
         self,
         name: str,
     ) -> int:
-        """read a single variable from scgi server as int"""
+        """Read a single variable from scgi server as int."""
         return await self.read_var(name, VarType.INT)
 
     @backoff.on_exception(
@@ -287,7 +297,7 @@ class Cybro:
         self,
         name: str,
     ) -> float:
-        """read a single variable from scgi server as float"""
+        """Read a single variable from scgi server as float."""
         return await self.read_var(name, VarType.FLOAT)
 
     @backoff.on_exception(
@@ -297,15 +307,15 @@ class Cybro:
         self,
         name: str,
     ) -> bool:
-        """read a single variable from scgi server as float"""
+        """Read a single variable from scgi server as float."""
         return await self.read_var(name, VarType.BOOL)
 
     def add_var(self, name: str) -> None:
-        """add a variable into update buffer"""
+        """Add a variable into update buffer."""
         self._device.add_var(name)
 
     def remove_var(self, name: str) -> None:
-        """remove a variable from update buffer"""
+        """Remove a variable from update buffer."""
         self._device.remove_var(name)
 
     async def __aenter__(self) -> Cybro:
@@ -322,3 +332,60 @@ class Cybro:
         Args:
             _exc_info: Exec type.
         """
+
+
+def _get_chunk(data, chunk_size):
+    """Split dictionary into smaller chunks."""
+    data_it = iter(data)
+    for i in range(0, len(data), chunk_size):
+        yield {k: data[k] for k in islice(data_it, chunk_size)}
+
+
+def _add_hiq_tags(
+    variables: dict[str, str], controller: str = "c10000."
+) -> dict[str, str]:
+    """Adds controller specific general error tags.
+
+    Args:
+        variables: current list of variables to add to it
+        controller: controller prefix (Default: c10000.)
+
+    Returns:
+        An updated dictionary of variables that includes HIQ controller specific variables.
+    """
+    _vars = variables
+    _vars[controller + "lc00_general_error"] = ""
+    _vars[controller + "lc01_general_error"] = ""
+    _vars[controller + "lc02_general_error"] = ""
+    _vars[controller + "lc03_general_error"] = ""
+    _vars[controller + "lc04_general_error"] = ""
+    _vars[controller + "lc05_general_error"] = ""
+    _vars[controller + "lc06_general_error"] = ""
+    _vars[controller + "lc07_general_error"] = ""
+    _vars[controller + "ld00_general_error"] = ""
+    _vars[controller + "ld01_general_error"] = ""
+    _vars[controller + "ld02_general_error"] = ""
+    _vars[controller + "ld03_general_error"] = ""
+    _vars[controller + "bc00_general_error"] = ""
+    _vars[controller + "bc01_general_error"] = ""
+    _vars[controller + "bc02_general_error"] = ""
+    _vars[controller + "bc03_general_error"] = ""
+    _vars[controller + "bc04_general_error"] = ""
+    _vars[controller + "bc05_general_error"] = ""
+    _vars[controller + "sc00_general_error"] = ""
+    _vars[controller + "sc01_general_error"] = ""
+    _vars[controller + "sc02_general_error"] = ""
+    _vars[controller + "sc03_general_error"] = ""
+    _vars[controller + "th00_general_error"] = ""
+    _vars[controller + "th01_general_error"] = ""
+    _vars[controller + "th02_general_error"] = ""
+    _vars[controller + "th03_general_error"] = ""
+    _vars[controller + "th04_general_error"] = ""
+    _vars[controller + "th05_general_error"] = ""
+    _vars[controller + "fc00_general_error"] = ""
+    _vars[controller + "fc01_general_error"] = ""
+    _vars[controller + "fc02_general_error"] = ""
+    _vars[controller + "fc03_general_error"] = ""
+    _vars[controller + "fc04_general_error"] = ""
+    _vars[controller + "fc05_general_error"] = ""
+    return _vars
